about summary refs log tree commit diff
path: root/misc/search.h
diff options
context:
space:
mode:
Diffstat (limited to 'misc/search.h')
-rw-r--r--misc/search.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/misc/search.h b/misc/search.h
index 5e237a2791..158332cd61 100644
--- a/misc/search.h
+++ b/misc/search.h
@@ -70,7 +70,7 @@ ENTRY;
 /* Opaque type for internal use.  */
 struct _ENTRY;
 
 /* Data type for reentrent functions.  */
 struct hsearch_data
   {
     struct _ENTRY *table;
@@ -79,7 +79,7 @@ struct hsearch_data
   };
 
 /* Family of hash table handling functions.  The functions also have
-   reentrent counterparts ending with _r.  */
+   reentrant counterparts ending with _r.  */
 extern ENTRY *hsearch __P ((ENTRY __item, ACTION __action));
 extern int hcreate __P ((unsigned int __nel));
 extern void hdestroy __P ((void));
@@ -70,7 +70,7 @@ ENTRY;
 struct _ENTRY;
 
-/* Data type for reentrent functions.  */
+/* Data type for reentrant functions.  */
 struct hsearch_data
   {